@@ -16,8 +16,6 @@ tiddler.type matches 'image/' then the link is an <img> tag.
 Otherwise an anchor.
 """
 
-import html5lib
-from html5lib import treebuilders
 from base64 import b64encode
 
 from tiddlyweb.serializer import NoSerializationError
@@ -26,6 +24,7 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.web.util import (server_base_url, tiddler_url,
         encode_name, html_encode, escape_attribute_value)
+from tiddlyweb.web.handler.tiddler import _tiddler_etag
 from tiddlywebplugins.wikklytextrender import wikitext_to_wikklyhtml
 
 
@@ -48,19 +47,6 @@ class Serialization(SerializationInterface):
     TiddlyWikis into the system.
     """
 
-    def as_bag(self, bag, input_string):
-        """
-        Turn a wiki into a bunch of tiddlers
-        stored in the bag.
-        """
-        try:
-            from tiddlywebplugins.twimport import wiki_string_to_tiddlers
-            tiddlers = wiki_string_to_tiddlers(input_string)
-            bag.add_tiddlers(tiddlers)
-            return bag
-        except ImportError:
-            raise NoSerializationError
-
     def list_tiddlers(self, bag):
         """
         Take the tiddlers from the given bag and inject
@@ -158,7 +144,7 @@ the content of this wiki</a>.
             tiddler_count += 1
 
         if tiddler_count == 1:
-            default_tiddler = Tiddler('DefaultTiddlers')
+            default_tiddler = Tiddler('DefaultTiddlers', '_virtual')
             default_tiddler.text = '[[' + tiddler.title + ']]'
             lines.append(self._tiddler_as_div(default_tiddler))
 
@@ -187,20 +173,14 @@ the content of this wiki</a>.
         text.
         """
         output = wikitext_to_wikklyhtml('', '', unicode(title), self.environ)
-        parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder('dom'))
-        dom = parser.parse(output)
-
-        def _get_text(nodelist):
-            text = ''
-            for node in nodelist:
-                if node.nodeType == node.TEXT_NODE:
-                    text = text + node.data
-                if node.childNodes:
-                    text = text + _get_text(node.childNodes)
-            return text
-
-        title = _get_text(dom.childNodes)
-        return ''.join(title).rstrip().lstrip()
+        rights = output.split('>')
+        lefts = []
+        for chunk in rights:
+            try:
+                lefts.append(chunk[0:chunk.index('<')])
+            except ValueError:
+                lefts.append(chunk)
+        return ''.join(lefts)
 
     def _determine_title(self, title, window_title, candidate_title, candidate_subtitle):
         """
@@ -269,6 +249,7 @@ the content of this wiki</a>.
             tiddler.type = ''
 
         return ('<div title="%s" server.title="%s" server.page.revision="%s" '
+                'server.etag="%s" '
                 'modifier="%s" creator="%s" server.workspace="bags/%s" '
                 'server.type="tiddlyweb" server.host="%s" '
                 'server.recipe="%s" server.bag="%s" server.permissions="%s" '
@@ -278,6 +259,8 @@ the content of this wiki</a>.
                     (escape_attribute_value(tiddler.title),
                         escape_attribute_value(tiddler.title),
                         tiddler.revision,
+                        escape_attribute_value(_tiddler_etag(
+                            self.environ, tiddler)),
                         escape_attribute_value(tiddler.modifier),
                         escape_attribute_value(tiddler.creator),
                         escape_attribute_value(tiddler.bag),
